.. Copyright 2020 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.bootstrap.page
-------------------------------

.. automodule:: reahl.web.bootstrap.page


HTML5Page
"""""""""

.. autoclass:: HTML5Page
   :members:

ErrorMessageBox
"""""""""""""""

.. autoclass:: ErrorMessageBox
   :members:

